# JVol

This is the documentation for JVol.

JVol is an experimental image file format for 3D images compressed using a simplified version of the JPEG algorithm.
The compression is lossy and therefore not suitable for all applications, e.g., diagnosis or quantitative analysis.

There are several situations in which preserving full quality is not crucial and JVol can be useful:

- Data needs to be transmitted quickly, or over a slow network
- Storage space is limited
- Tests for continuous integration
- Quick debugging and development
- Online demos
